import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

Future<void> showPopUpFilterMenu({
  required BuildContext context,
  Function()? onSortAtoZ,
  Function()? onSortZtoA,
  Function()? cancelButton,
  required Map<String, bool> checkboxStates,
  Function()? onOkPressed,
  List<String>? list,
}) async {
  final RenderBox overlay =
      Overlay.of(context).context.findRenderObject() as RenderBox;

  await showMenu(
    context: context,
    position: RelativeRect.fromLTRB(
      overlay.size.width / 4,
      240,
      overlay.size.width / 4,
      0,
    ),
    color: ColorsManager.whiteColors,
    shape: const RoundedRectangleBorder(
      borderRadius: BorderRadius.all(Radius.circular(10)),
    ),
    items: <PopupMenuEntry>[
      PopupMenuItem(
        onTap: onSortAtoZ,
        child: ListTile(
          leading: Image.asset(
            Assets.AtoZIcon,
            width: 25,
          ),
          title: const Text(
            "Sort A to Z",
            style: TextStyle(color: Colors.blueGrey),
          ),
        ),
      ),
      PopupMenuItem(
        onTap: onSortZtoA,
        child: ListTile(
          leading: Image.asset(
            Assets.ZtoAIcon,
            width: 25,
          ),
          title: const Text(
            "Sort Z to A",
            style: TextStyle(color: Colors.blueGrey),
          ),
        ),
      ),
      const PopupMenuDivider(),
      const PopupMenuItem(
        child: Text(
          "Filter by Status",
          style: TextStyle(fontWeight: FontWeight.bold),
        ),
      ),
      PopupMenuItem(
        child: SizedBox(
          height: 200,
          width: 400,
          child: ListView.builder(
            itemCount: list?.length ?? 0,
            itemBuilder: (context, index) {
              final item = list![index];
              return CheckboxListTile(
                title: Text(item),
                value: checkboxStates[item],
                onChanged: (bool? newValue) {
                  checkboxStates[item] = newValue ?? false;
                  (context as Element).markNeedsBuild();
                },
              );
            },
          ),
        ),
      ),
      PopupMenuItem(
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            GestureDetector(
              onTap: () {
                Navigator.of(context).pop(); // Close the menu
              },
              child: const Text("Cancel"),
            ),
            GestureDetector(
              onTap: onOkPressed,
              child: const Text(
                "OK",
                style: TextStyle(
                  color: ColorsManager.spaceColor,
                ),
              ),
            ),
          ],
        ),
      ),
    ],
  );
}
